@@ -188,6 +188,7 @@ class BaseHandler(RequestHandler):
             handler_method = res[0][1]
             # 最终整理后的请求参数集合
             params_list = []
+            params_dict = {}
             # 获取当前请求的Content-Type
             content_type = self.request.headers.get('Content-Type')
             # 当前请求参数
@@ -210,6 +211,7 @@ class BaseHandler(RequestHandler):
                 # 如果参数是self 做特殊处理，传入本身
                 if parameter_name == 'self':
                     params_list.append(self)
+                    params_dict.update({"self": self})
                 else:
                     # 依据参数名称，获取请求参数值
                     argument_value = arguments.get(parameter_name)
@@ -218,6 +220,7 @@ class BaseHandler(RequestHandler):
                         # 查看是否有默认值，如果有直接跳过即可
                         if parameter.default is not inspect.Parameter.empty:
                             params_list.append(parameter.default)
+                            params_dict.update({parameter_name: parameter.default})
                             continue
                         else:
                             # 如果没有有默认值，要抛出异常 提示"请求缺少必要参数"
@@ -237,13 +240,18 @@ class BaseHandler(RequestHandler):
                             if len(argument_value) == 1:
                                 # 仅一个 直接存入
                                 params_list.append(parse_val(argument_value[0], parameter_type))
+                                params_dict.update({parameter_name: parse_val(argument_value[0], parameter_type)})
                             else:
                                 # 多个要使用集合存入
                                 params_list.append([parse_val(v, parameter_type) for v in argument_value])
+                                params_dict.update(
+                                    {parameter_name: [parse_val(v, parameter_type) for v in argument_value]})
                         else:
                             params_list.append([parse_val(v, parameter_type) for v in argument_value])
+                            params_dict.update({parameter_name: [parse_val(v, parameter_type) for v in argument_value]})
                     else:
                         params_list.append(parse_val(argument_value, parameter_type))
+                        params_dict.update({parameter_name: parse_val(argument_value, parameter_type)})
 
             # 判断是否为异步非阻塞方法，true 则直接调用
             try:
@@ -251,7 +259,8 @@ class BaseHandler(RequestHandler):
                     data = await handler_method(*params_list)
                 else:
                     # 阻塞方法异步调用
-                    data = await IOLoop.current().run_in_executor(None, handler_method, *params_list)
+                    func = lambda: handler_method(**params_dict)
+                    data = await IOLoop.current().run_in_executor(None, func)
                 self.end_time = int(round(time.time() * 1000))
                 self.set_header("Api-Time", f"{self.end_time - self.start_time}ms")
                 self.process_response(data)
